@@ -252,7 +252,7 @@ mkNewReTrms <- function(object, newdata, re.form=NULL, na.action=na.pass,
         if (!allow.new.levels && any(vapply(ReTrms$flist, anyNA, NA)))
             stop("NAs are not allowed in prediction data",
                  " for grouping variables unless allow.new.levels is TRUE")
-        ns.re <- names(re <- ranef(object))
+        ns.re <- names(re <- ranef(object, condVar = FALSE))
         nRnms <- names(Rcnms <- ReTrms$cnms)
         if (!all(nRnms %in% ns.re))
             stop("grouping factors specified in re.form that were not present in original model")
@@ -679,10 +679,13 @@ simulate.merMod <- function(object, nsim = 1, seed = NULL, use.u = FALSE,
             if(nullWts) weights <- rowSums(r)
         }
 
-        if (is.null(sfun <- simfunList[[family$family]]) &&
-            is.null(family$simulate))
-            stop("simulation not implemented for family",
-                 family$family)
+        if (is.null(sfun <- simfunList[[family$family]])) {
+            ## family$simulate just won't work ...
+            ## sim funs must be hard-coded, see below
+            stop("simulation not implemented for family ",
+                 sQuote(family$family))
+        }
+
         ## don't rely on automatic recycling
         if (cond.sim) {
              val <- sfun(object, nsim=1, ftd = rep_len(musim, n*nsim),
@@ -719,11 +722,10 @@ simulate.merMod <- function(object, nsim = 1, seed = NULL, use.u = FALSE,
     row.names(val) <- nm
 
     fit.na.action <- attr(model.frame(object), "na.action")
-
     if (!missing(na.action) &&  !is.null(fit.na.action)) {
         ## retrieve name of na.action type ("omit", "exclude", "pass")
         class.na.action <- class(attr(na.action(NA), "na.action"))
-        if (class.na.action != class(fit.na.action)) {
+        if (!identical(class.na.action, class(fit.na.action))) {
             ## hack to override action where explicitly specified
             class(fit.na.action) <- class.na.action
         }
@@ -778,7 +780,6 @@ simulate.merMod <- function(object, nsim = 1, seed = NULL, use.u = FALSE,
 ## (2) modifying wts from object$prior.weights to weights(object)
 ## (3) adding wts as an argument
 ##
-##
 ## these can be incorporated by overwriting the simulate()
 ## components, or calling them
 ##
@@ -857,24 +858,20 @@ gamma.shape.merMod <- function(object, ...) {
               class = "gamma.shape")
 }
 
-
-## FIXME: include without inducing SuppDists dependency?
-## inverse.gaussian_simfun <- function(object, nsim, ftd=fitted(object)) {
-##     if(is.null(tryCatch(loadNamespace("SuppDists"),
-##                         error = function(e) NULL)))
-##         stop("need CRAN package 'SuppDists' for the 'inverse.gaussian' family")
-##     wts <- weights(object)
-##     if (any(wts != 1)) message("using weights as inverse variances")
-##     SuppDists::rinvGauss(nsim * length(ftd), nu = ftd,
-##                          lambda = wts/summary(object)$dispersion)
-## }
+inverse.gaussian_simfun <- function(object, nsim, ftd=fitted(object),
+                                    wts = weights(object)) {
+    if (any(wts != 1)) message("using weights as inverse variances")
+    statmod::rinvgauss(nsim * length(ftd), mean = ftd,
+                       shape= wts/sigma(object))
+}
 
 ## in the original MASS version, .Theta is assigned into the environment
 ## (triggers a NOTE in R CMD check)
 ## modified from @aosmith16 GH contribution
 
-negative.binomial_simfun <- function (object, nsim, ftd = fitted(object),
-                                          wts=weights(object))
+negative.binomial_simfun <- function (object, nsim,
+                                      ftd = fitted(object),
+                                      wts=weights(object))
 {
 
     if (any(wts != 1))
@@ -883,9 +880,9 @@ negative.binomial_simfun <- function (object, nsim, ftd = fitted(object),
     rnbinom(nsim * length(ftd), mu = ftd, size = theta)
 }
 
-
 simfunList <- list(gaussian = gaussian_simfun,
                    binomial = binomial_simfun,
                    poisson  = poisson_simfun,
                    Gamma    = Gamma_simfun,
-                   negative.binomial = negative.binomial_simfun)
+                   negative.binomial = negative.binomial_simfun,
+                   inverse.gaussian = inverse.gaussian_simfun)
