@@ -10,11 +10,24 @@ dd$y <- rnbinom(nrow(dd), mu = mu, size = 0.5)
 
 ## mimic glmer.nb protocol
 
+test_that("most messages suppressed", {
+    expect_message(glmer.nb(y ~ f1 + (1|g), data=dd[1:10,]),
+                   "singular")
+})
+
+test_that("ok with negative.binomial masking", {
+    negative.binomial <- function() {}
+    ## use shortened version of data for speed ...
+    m.base <- glmer.nb(y ~ f1 + (1|g), data=dd[1:200,])
+    expect_is(m.base,"merMod")
+})
+
 test_that("ok with Poisson masking", {
     poisson <- NA
     ## use shortened version of data for speed ...
     m.base <- glmer.nb(y ~ f1 + (1|g), data=dd[1:200,])
     expect_is(m.base,"merMod")
+    rm(poisson)
 })
 
 context("testing glmer refit")
@@ -31,31 +44,31 @@ test_that("glmer refit", {
             th2 <- 0.482681268108477
             th3 <- 0.4826813
             ## NB update with raw number
-            m.numth1 <- update(m.base,family=negative.binomial(theta=0.4826813))
+            m.numth1 <- update(m.base,family=MASS::negative.binomial(theta=0.4826813))
             expect_equal(m.numth1@beta,(m.numth1.r <- refit(m.numth1))@beta)
 
             ## strip NB value
-            m.symth4 <- update(m.base,family=negative.binomial(theta=c(th)))
+            m.symth4 <- update(m.base,family=MASS::negative.binomial(theta=c(th)))
             expect_equal(m.symth4@beta,(m.symth4.r <- refit(m.symth4))@beta)
 
             ## IDENTICAL numeric value to case #1 above
-            m.symth6 <- update(m.base,family=negative.binomial(theta=th3))
+            m.symth6 <- update(m.base,family=MASS::negative.binomial(theta=th3))
             expect_equal(m.symth6@beta,(m.symth6.r <- refit(m.symth6))@beta)
 
             ## standard NB update with computed theta from est_theta (incl SE attribute)
-            m.symth <- update(m.base,family=negative.binomial(theta=th))
+            m.symth <- update(m.base,family=MASS::negative.binomial(theta=th))
             expect_equal(m.symth@beta,(m.symth.r <- refit(m.symth))@beta)
 
             ## NB update with equivalent value
-            m.symth2 <- update(m.base,family=negative.binomial(theta=th0))
+            m.symth2 <- update(m.base,family=MASS::negative.binomial(theta=th0))
             expect_equal(m.symth2@beta,(m.symth2.r <- refit(m.symth2))@beta) 
 
             ## NB update with theta value (stored as variable, no SE) only
-            m.symth3 <- update(m.base,family=negative.binomial(theta=th1))
+            m.symth3 <- update(m.base,family=MASS::negative.binomial(theta=th1))
             expect_equal(m.symth3@beta,(m.symth3.r <- refit(m.symth3))@beta)
 
             ## strip NB value (off by 5e-16)
-            m.symth5 <- update(m.base,family=negative.binomial(theta=th2))
+            m.symth5 <- update(m.base,family=MASS::negative.binomial(theta=th2))
             expect_equal(m.symth5@beta,(m.symth5.r <- refit(m.symth5))@beta)
         })
 
